==> arm-compute-library_23.08+dfsg.orig.tar.xz: arm-compute-library-23.08+dfsg/src/core/CL/kernels/CLQLSTMLayerNormalizationKernel.h <==
/*
 * Copyright (c) 2020 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H
#define ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H

#include "src/core/CL/ICLKernel.h"

namespace arm_compute
{
class ICLTensor;

/** Interface for the kernel to do layer normalization. */
class CLQLSTMLayerNormalizationKernel : public ICLKernel
{
public:
    /** Default constructor */
    CLQLSTMLayerNormalizationKernel();
    /** Prevent instances of this class from being copied (As this class contains pointers) */
    CLQLSTMLayerNormalizationKernel(const CLQLSTMLayerNormalizationKernel &) = delete;
    /** Prevent instances of this class from being copied (As this class contains pointers) */
    CLQLSTMLayerNormalizationKernel &operator=(const CLQLSTMLayerNormalizationKernel &) = delete;
    /** Allow instances of this class to be moved */
    CLQLSTMLayerNormalizationKernel(CLQLSTMLayerNormalizationKernel &&) = default;
    /** Allow instances of this class to be moved */
    CLQLSTMLayerNormalizationKernel &operator=(CLQLSTMLayerNormalizationKernel &&) = default;
    /** Default destructor */
    ~CLQLSTMLayerNormalizationKernel() = default;
    /** Initialise the kernel's input and outputs.
     *
     * @param[in]  input  Source tensor with 2 dimensions. Data types supported: QSYMM16.
     * @param[out] output Destination tensor. Data type supported: same as @p input
     * @param[in]  weight Weight tensor. Data types supported: Same as @p input.
     * @param[in]  bias   Bias tensor. Data types supported: S32.
     *
     */
    void configure(const ICLTensor *input, ICLTensor *output, const ICLTensor *weight, const ICLTensor *bias);
    /** Initialise the kernel's input and outputs.
     *
     * @param[in]  compile_context The compile context to be used.
     * @param[in]  input           Source tensor with 2 dimensions. Data types supported: QSYMM16.
     * @param[out] output          Destination tensor. Data type supported: same as @p input
     * @param[in]  weight          Weight tensor. Data types supported: Same as @p input.
     * @param[in]  bias            Bias tensor. Data types supported: S32.
     */
    void configure(const CLCompileContext &compile_context, const ICLTensor *input, ICLTensor *output, const ICLTensor *weight, const ICLTensor *bias);
    /** Static function to check if given info will lead to a valid configuration of @ref CLQLSTMLayerNormalizationKernel
     *
     * @param[in] input  Source tensor info with 2 dimensions. Data types supported: QSYMM16.
     * @param[in] output Destination info tensor. Data type supported: same as @p input
     * @param[in] weight Weight info tensor. Data types supported: Same as @p input.
     * @param[in] bias   Bias tensor info. Data types supported: S32.
     *
     * @return a status
     */
    static Status validate(const ITensorInfo *input, const ITensorInfo *output, const ITensorInfo *weight, const ITensorInfo *bias);

    // Inherited methods overridden:
    void run(const Window &window, cl::CommandQueue &queue) override;

private:
    const ICLTensor *_input;
    const ICLTensor *_weight;
    const ICLTensor *_bias;
    ICLTensor       *_output;
};
} // namespace arm_compute
#endif /* ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H */

==> arm-compute-library_24.11+dfsg.orig.tar.xz: arm-compute-library-24.11+dfsg/src/core/CL/kernels/CLQLSTMLayerNormalizationKernel.h <==
/*
 * Copyright (c) 2020 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H
#define ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H

#include "src/core/CL/ICLKernel.h"

namespace arm_compute
{
class ICLTensor;

/** Interface for the kernel to do layer normalization. */
class CLQLSTMLayerNormalizationKernel : public ICLKernel
{
public:
    /** Default constructor */
    CLQLSTMLayerNormalizationKernel();
    /** Prevent instances of this class from being copied (As this class contains pointers) */
    CLQLSTMLayerNormalizationKernel(const CLQLSTMLayerNormalizationKernel &) = delete;
    /** Prevent instances of this class from being copied (As this class contains pointers) */
    CLQLSTMLayerNormalizationKernel &operator=(const CLQLSTMLayerNormalizationKernel &) = delete;
    /** Allow instances of this class to be moved */
    CLQLSTMLayerNormalizationKernel(CLQLSTMLayerNormalizationKernel &&) = default;
    /** Allow instances of this class to be moved */
    CLQLSTMLayerNormalizationKernel &operator=(CLQLSTMLayerNormalizationKernel &&) = default;
    /** Default destructor */
    ~CLQLSTMLayerNormalizationKernel() = default;
    /** Initialise the kernel's input and outputs.
     *
     * @param[in]  input  Source tensor with 2 dimensions. Data types supported: QSYMM16.
     * @param[out] output Destination tensor. Data type supported: same as @p input
     * @param[in]  weight Weight tensor. Data types supported: Same as @p input.
     * @param[in]  bias   Bias tensor. Data types supported: S32.
     *
     */
    void configure(const ICLTensor *input, ICLTensor *output, const ICLTensor *weight, const ICLTensor *bias);
    /** Initialise the kernel's input and outputs.
     *
     * @param[in]  compile_context The compile context to be used.
     * @param[in]  input           Source tensor with 2 dimensions. Data types supported: QSYMM16.
     * @param[out] output          Destination tensor. Data type supported: same as @p input
     * @param[in]  weight          Weight tensor. Data types supported: Same as @p input.
     * @param[in]  bias            Bias tensor. Data types supported: S32.
     */
    void configure(const CLCompileContext &compile_context,
                   const ICLTensor        *input,
                   ICLTensor              *output,
                   const ICLTensor        *weight,
                   const ICLTensor        *bias);
    /** Static function to check if given info will lead to a valid configuration of @ref CLQLSTMLayerNormalizationKernel
     *
     * @param[in] input  Source tensor info with 2 dimensions. Data types supported: QSYMM16.
     * @param[in] output Destination info tensor. Data type supported: same as @p input
     * @param[in] weight Weight info tensor. Data types supported: Same as @p input.
     * @param[in] bias   Bias tensor info. Data types supported: S32.
     *
     * @return a status
     */
    static Status
    validate(const ITensorInfo *input, const ITensorInfo *output, const ITensorInfo *weight, const ITensorInfo *bias);

    // Inherited methods overridden:
    void run(const Window &window, cl::CommandQueue &queue) override;

private:
    const ICLTensor *_input;
    const ICLTensor *_weight;
    const ICLTensor *_bias;
    ICLTensor       *_output;
};
} // namespace arm_compute
#endif /* ARM_COMPUTE_CLQLSTMLAYERVNORMALIZATIONKERNEL_H */
